@@ -12,12 +12,30 @@ from mw_python_sdk import download_dir, download_file, upload_file
 # --quantization bitsandbytes --load-format bitsandbytes --enforce-eager
 
 
+def get_first_gpu_type():
+    # Run the nvidia-smi command to get GPU info
+    result = subprocess.run(
+        ["nvidia-smi", "-L"], stdout=subprocess.PIPE, stderr=subprocess.PIPE, text=True
+    )
+
+    if result.returncode != 0:
+        raise Exception(
+            "Error executing nvidia-smi. Ensure NVIDIA drivers are installed and nvidia-smi is accessible."
+        )
+
+    # Extract the first GPU from the output
+    gpu_info = result.stdout.strip().split("\n")[0]
+    # Extract the GPU type (e.g., NVIDIA H20)
+    gpu_type = gpu_info.split(":")[1].strip().split(" ")[0]
+
+    return gpu_type
+
 def serve(
     model_id: str,
     model_name: str,
     host: str = "127.0.0.1",
     port: int = 8080,
-    dtype: str = "half",
+    dtype: str = "auto",
     max_model_len: int = 4096,
     max_num_seq: int = 2,
     tensor_parallel_size: int = 1,
@@ -34,6 +52,9 @@ def serve(
             model_dir = download_dir(model_id)
             if model_name == "":
                 model_name = model_id
+        gpu_type = get_first_gpu_type()
+        if "V100" in gpu_type:
+            dtype = "half"
         # quantization
         extra_arguments = ""
         if quantization:
